# AI Project 

Linear and Logistic Regression both mostly use Gradient Descent as their optimization algorithm


This project makes use of **Genetic Algorithm**  instead to optimize the Weights and Biases

Genetic Algorithm follows:-

1. Initialization
2. Selection 
3. Crossover 
4. Mutation 
5. Termination 


To learn more about Genetic Algorithm [click here](https://en.wikipedia.org/wiki/Genetic_algorithm)

Github - [Here](https://github.com/Amaaan09/Genetic-pypi) 